<?php

namespace FiloBlu\AdyenErrorNotificationHandler\Helper;

use FiloBlu\AdyenErrorNotificationHandler\Helper\CustomLogger;
use Magento\Framework\App\Config\ScopeConfigInterface;

class Data
{
    const ADYEN_ERROR_NOTIFICATION_HANDLER_ENABLED_CONFIG_PATH = 'adyen_error_notification_handler/general/error_notification_enabled';
    const ADYEN_ERROR_NOTIFICATION_HANDLER_MESSAGES_CONFIG_PATH = 'adyen_error_notification_handler/general/error_notification_messages';
    const ADYEN_ERROR_NOTIFICATION_HANDLER_GENERAL_USE_DEFAULT_LANG = 'adyen_error_notification_handler/general/use_default_lang';
    const ADYEN_REFUSAL_REASON_CODE = 'refusalReasonCode';
    const ERROR_CODE_3DV1 = '3dv1';
    const DEFAULT_STORE = 'default';

    /**
     * @var ScopeConfigInterface
     */
    protected $config;

    /**
     * @var CustomLogger
     */
    protected $customLogger;

    public function __construct(
        ScopeConfigInterface $config,
        CustomLogger         $customLogger
    )
    {
        $this->config = $config;
        $this->customLogger = $customLogger;
    }

    public function adyenErrorNotificationHandlerIsEnabled()
    {
        return $this->config->isSetFlag(self::ADYEN_ERROR_NOTIFICATION_HANDLER_ENABLED_CONFIG_PATH);
    }

    public function getAdyenErrorNotificationMessages()
    {
        return $this->config->getValue(self::ADYEN_ERROR_NOTIFICATION_HANDLER_MESSAGES_CONFIG_PATH);
    }

    public function useErrorMessagesInDefaultLangEnabled()
    {
        return $this->config->isSetFlag(self::ADYEN_ERROR_NOTIFICATION_HANDLER_GENERAL_USE_DEFAULT_LANG);
    }

    public function getErrorsInLanguage($errorsList, $languageIso)
    {
        if (isset($errorsList[$languageIso])) {
            return $errorsList[$languageIso];
        }

        $language = explode('_', $languageIso);

        foreach ($language as $lang) {
            if (isset($errorsList[$lang])) {
                return $errorsList[$lang];
            }
        }

        return null;
    }

    public function getErrorByCode($errorsList, $errorCode)
    {
        if (isset($errorsList[$errorCode])) {
            return $errorsList[$errorCode];
        }

        return null;
    }

    public function getDefaultLang()
    {
        return $this->config->getValue(
            \Magento\Directory\Helper\Data::XML_PATH_DEFAULT_LOCALE,
            self::DEFAULT_STORE
        );
    }

    public function manageDataToLog($data)
    {
        $this->customLogger->log('*********');
        $this->customLogger->log('User language: ' . $data['lang']);

        if ($data['3ds_v1']) {
            $this->customLogger->log('3d secure V1 transaction');
        }

        if (isset($data['response']['pspReference'])) {
            $this->customLogger->log('Adyen pspReference: ' . $data['response']['pspReference']);
        }
        if (isset($data['response']['refusalReason'])) {
            $this->customLogger->log('Adyen refusalReason: ' . $data['response']['refusalReason']);
        }
        if (isset($data['response']['resultCode'])) {
            $this->customLogger->log('Adyen resultCode: ' . $data['response']['resultCode']);
        }
        if (isset($data['response']['refusalReasonCode'])) {
            $this->customLogger->log('Adyen refusalReasonCode: ' . $data['response']['refusalReasonCode']);
        } else {
            $this->customLogger->log("Adyen doesn't send refusalReasonCode!");
        }
        if (isset($data['response']['merchantReference'])) {
            $this->customLogger->log('Merchant Reference: ' . $data['response']['merchantReference']);
        }

        if (isset($data['module_error'])) {
            $this->customLogger->log('mod2-adyen-error-notification-handler returned the error: ' . $data['module_error']);
        }
    }
}